<?php
/**
 * @package Magazinex
 */
 
// Theme Constants.
define( 'MAGAZINEX_DIR', get_template_directory() );
define( 'MAGAZINEX_DIR_URI', get_template_directory_uri() );
define( 'MAGAZINEX_VERSION', '1.0.7' );
define( 'MAGAZINEX_WP_REQUIRES', '4.3' );
define( 'MAGAZINEX_PREMIUM', '1' );

if( version_compare( $GLOBALS['wp_version'], '4.3', '<' ) ) {
	// Magazinex only works in WordPress 4.3 or later.
	require get_template_directory() . '/includes/back-compat.php';
}

/**
 * 	Set the content width in pixels, based on the theme's design and stylesheet.
 * 	Priority 0 to make it available to lower priority callbacks.
 * 	@global int $content_width
 */
function magazinex_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'magazinex_content_width', 640 );

	//Adjust content_width value for page and attachement templates.
	if ( is_page_template( array( 'page-templates/full-width.php', 'page-templates/frontpage.php' ) )
	  || is_attachment() ) {
		$GLOBALS['content_width'] = 1021;
	}
}
add_action( 'after_setup_theme', 'magazinex_content_width', 0 );


/**
 *	Start things up.
 *-----------------------------------------------------------------*/
if( ! function_exists( 'magazinex_setup' ) ) {
	function magazinex_setup() {
		// Load translation domain.
		load_theme_textdomain( 'magazinex-lite', get_template_directory() . '/languages' );

		// RSS Feed links.
		add_theme_support( 'automatic-feed-links' );

		// Document title.
		add_theme_support( 'title-tag' );

		// Add Logo support
		add_theme_support( 'custom-logo' );

		// HTML5
		add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );

		// Editor styles.
		add_editor_style( array( 'css/editor-style.css', magazinex_fonts_url() ) );

		// Post formats.
		add_theme_support( 'post-formats', array( 'video', 'gallery', 'image', 'audio' ) );

		// Featured Image.
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 150, 150, true );

		add_image_size( 'magazinex-thumbnail', 470, 350, true );

		// Register Menus.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary Menu', 'magazinex-lite' ),
			'secondary' => esc_html__( 'Secondary Menu', 'magazinex-lite' ),
			'social'  => esc_html__( 'Social Links Menu', 'magazinex-lite' ),
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'magazinex_custom_background_args', array(
			'default-color' => '343b47',
			'default-image' => '',
		) ) );

		// Custom Header.
		add_theme_support( 'custom-header', apply_filters( 'magazinex_header_args', array(
			  'flex-width'  => true,
			  'flex-height' => true,
			  'width'       => 1440,
			  'height'      => 320,
			  'header-text' => false
		) ) );
	}
}
add_action( 'after_setup_theme', 'magazinex_setup' );



/**
 *	Register Google fonts.
 *-----------------------------------------------------------------*/
function magazinex_fonts_url() {
	$fonts_url     = '';
	$_defaults     = array( 'Lato:400,300,400italic,700,900' );
	$font_families = apply_filters( 'magazinex_font_families', $_defaults );
	$subsets       = apply_filters( 'magazinex_font_subsets', 'latin,latin-ext' );

	if ( $font_families ) {
		$font_families = array_unique( $font_families );
		$query_args    = array(
			  'family' => urlencode( implode( '|', $font_families ) ),
			  'subset' => urlencode( $subsets )
		);
		$fonts_url = esc_url( add_query_arg( $query_args, 'https://fonts.googleapis.com/css' ) );
	}

	return $fonts_url;
}



/**
 *	Register Widget area.
 *-----------------------------------------------------------------*/
function magazinex_widgets_init() {
	// Primary Widgets Area.
	register_sidebar( array(
		  'id'            => 'primary',
		  'name'          => esc_html__( 'Sidebar', 'magazinex-lite' ),
		  'description'   => esc_html__( 'Add widgets here to appear in your sidebar.', 'magazinex-lite' ),
		  'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
		  'after_widget'  => '</aside>',
		  'before_title'  => '<h4 class="widget-title">',
		  'after_title'   => '</h4>',
	) );
	// Front PageWidgets Area.
	register_sidebar( array(
		  'id'            => 'front-page',
		  'name'          => esc_html__( 'Front Page Area', 'magazinex-lite' ),
		  'description'   => esc_html__( 'Add widgets here to appear in the Front Page widgets area.', 'magazinex-lite' ),
		  'before_widget' => '<aside id="%1$s" class="widget col %2$s">',
		  'after_widget'  => '</aside>',
		  'before_title'  => '<h4 class="widget-title">',
		  'after_title'   => '</h4>',
	) );
	// Footer Widgets Area.
	register_sidebar( array(
		  'id'            => 'footer',
		  'name'          => esc_html__( 'Footer Area', 'magazinex-lite' ),
		  'description'   => esc_html__( 'Add widgets here to appear in the site footer.', 'magazinex-lite' ),
		  'before_widget' => '<aside id="%1$s" class="widget col %2$s">',
		  'after_widget'  => '</aside>',
		  'before_title'  => '<h5 class="widget-title">',
		  'after_title'   => '</h5>',
	) );
}
add_action( 'widgets_init', 'magazinex_widgets_init' );



/**
 *	Enqueue scripts and styles.
 *-----------------------------------------------------------------*/
function magazinex_enqueue_scripts() {
	// Main style.
	wp_enqueue_style( 'magazinex-lite', get_stylesheet_uri() );

	// styles.
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/font-awesome/css/font-awesome.min.css', array(), '4.6' );
	wp_enqueue_style( 'magazinex-fonts', magazinex_fonts_url(), array(), null );

	if ( wp_style_is( 'genericons', 'registered' ) ) {
		wp_enqueue_style( 'genericons' );
	} else {
		wp_enqueue_style( 'genericons', get_template_directory_uri() . '/genericons/genericons.css', array(), null );
	}

	if ( is_page_template( 'page-templates/frontpage.php' ) ) {
		wp_enqueue_style( 'content-slider', get_template_directory_uri() . '/css/content.slider.css', array(), null );
	}

	// scripts.
	wp_enqueue_script( 'jquery-masonry', array('jquery') );
	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/js/owl.carousel.min.js', array(), '1.3.3', true );
	wp_enqueue_script( 'jquery-fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array(), '1.1', true );
	wp_enqueue_script( 'magazinex-lite', get_template_directory_uri() . '/js/magazinex.js', array(), '1.0', true );

	// inclusion of the condition.
	wp_enqueue_script( 'html5', get_template_directory_uri() . '/js/html5.min.js', array(), '3.7.3' );
	wp_script_add_data( 'html5', 'conditional', 'lt IE 9' );

	if( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_page_template( 'page-templates/frontpage.php' ) ) {
		wp_enqueue_script( 'content-slider', get_template_directory_uri() . '/js/content.slider.js', array(), '1.0', true );
	}
}
add_action( 'wp_enqueue_scripts', 'magazinex_enqueue_scripts' );

/**
 * Load Dashboard welcome page.
 */
require get_template_directory() . '/includes/admin/magazinex-welcome-screen.php';

/**
 *	Theme Customizer.
 *-----------------------------------------------------------------*/
require get_template_directory() . '/customizer/config.php';

/**
 *	Theme Functions.
 *-----------------------------------------------------------------*/
require get_template_directory() . '/includes/term-meta-color.php';
require get_template_directory() . '/includes/external.php';
require get_template_directory() . '/includes/template-tags.php';
require get_template_directory() . '/includes/jetpack.php';

/**
 *	Theme Meta Boxes.
 *-----------------------------------------------------------------*/
require_once( get_template_directory() .'/includes/meta-pages.php' );

/**
 *	Theme Widgets.
 *-----------------------------------------------------------------*/
require_once( get_template_directory() .'/includes/widgets/widget-tabs.php' );