<?php
/**
 * @package Magazinex
 */

/**
 *	Custom Site Logo.
 *-----------------------------------------------------------------*/
if( ! function_exists( 'magazinex_site_title' ) ) {
	function magazinex_site_title() {
		if ( function_exists( 'the_custom_logo' ) ) {
			$image = wp_get_attachment_image_src( get_theme_mod( 'custom_logo' ), 'full' );
			$logo = esc_url( $image[0] );
		} else {
			$logo = esc_url( get_theme_mod( 'logo' ) );
		}
		$name = esc_attr( get_bloginfo( 'name' ) );
		if( !empty( $logo ) ) {
			$site_logo = '<img src="'. $logo .'" alt="'. $name .'" />';
		}
		else {
			$site_logo = esc_attr( $name );
		}

		$site_logo = apply_filters( 'magazinex_site_title', $site_logo );
		$attr = 'div';

		$output = sprintf( '<%1$s class="site-title"><a href="%2$s" rel="home">%3$s</a></%1$s>', $attr, esc_url( home_url( '/' ) ), $site_logo );
		echo $output;
	}
}



/**
 * Social Links Menu
 */
function magazinex_social_menu() {
	if ( has_nav_menu( 'social' ) ) : ?>
	<div class="social-navigation" role="link">
		<?php wp_nav_menu( array(
					'theme_location' => 'social',
					'link_before' => '<span class="screen-reader-text">',
					'link_after' => '</span>',
					'depth' => 1,
				) ); ?>
	</div><!-- .social-navigation -->
<?php
	endif;
}



/**
 *	Post featured image
 *-----------------------------------------------------------------*/
if( ! function_exists( 'magazinex_post_preview' ) ) {
	function magazinex_post_preview() {
		global $post;
		$post_id = $post->ID;
		$output  = '';
		
		// Standard Post / Page.
		if( has_post_thumbnail( $post_id ) ) {
			global $content_width;
			$thumb_src = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'full' );
			$width     = is_array( $thumb_src ) ? $thumb_src[1] : 0;
			if( $width >= $content_width ) {
				if( is_singular() ) {
					if( get_theme_mod('hide_featured_image') != true ) {
						$output = get_the_post_thumbnail( $post_id, 'full' );
					}
				}
				else {
					$layout = magazinex_external_current_layout();
					$size   = ( 'layout-default' == $layout ) ? 'full' : 'magazinex-thumbnail';
					$output = sprintf( '<a href="%s" class="thumb-link">%s</a>', esc_url( get_permalink( $post_id ) ), get_the_post_thumbnail( $post_id, $size ) );
				}
			}
		}
		
		// Post Formats.
		if ( has_post_format( array( 'image' ) ) && ! has_post_thumbnail() || is_single() && ! has_post_format( 'image' ) ) :
			$output  = apply_filters( 'magazinex_post_formats', $post_id, $output );
		endif;
		if( $output != '' ) {
			printf( '<div class="post-media">%s</div><!-- .post-media -->', $output );
		}

	} // function
}

/**
 *	Related Posts Box.
 *-----------------------------------------------------------------*/
if( ! function_exists( 'magazinex_tags_related_posts' ) ) {
	function magazinex_tags_related_posts() {
		global $post;
		$post_id    = $post->ID;
		$categories = get_the_category( $post_id );
		if( $categories ) {
			$category__in = array();
			foreach( $categories as $cat ) {
				$category__in[] = $cat->term_id;
			}
			$related = new WP_Query( array(
						'posts_per_page'      	=> 3,
						'ignore_sticky_posts' => true,
						'post__not_in'        	=> array( $post_id ),
						'category__in'        	=> $category__in,
						'orderby'             	=> 'rand',
						) );

			if( $related->have_posts() ) { ?>

<div class="related-posts boxed-content clearfix">
	<h4 class="related-title"><?php esc_attr_e( 'Related Articles', 'magazinex-lite' ); ?></h4>
	<ul>
		<?php
			$item_index = 0;
			while( $related->have_posts() ) {
				$related->the_post();
				$item_index++;
			?>

		<li class="related-item-<?php echo $item_index; ?>">
			<?php	
				if( has_post_thumbnail() ) {
					printf( '<a href="%1$s" class="thumb-link">%2$s</a>', esc_url( get_permalink() ),
					get_the_post_thumbnail( get_the_ID(),'magazinex-thumbnail' ) );
				}

				if( has_post_thumbnail() ) {
					echo '<div class="relate-item-inner has-thumb">';
				} else {
					echo '<div class="relate-item-inner">';
				}

					the_title( '<h5><a href="'.esc_url( get_permalink() ).'" title="'. the_title_attribute( array('echo' => 0) ) .'">', '</a></h5>' );

					echo '</div>';
					?>
		</li>
		<?php
			}
			wp_reset_postdata(); ?>

					</ul>
				</div><!-- .related-posts -->
		<?php
			} // have_posts
			wp_reset_postdata();
		} // categories
	}
}

if ( ! function_exists( 'magazinex_post_metadate' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time only
 */
function magazinex_post_metadate() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$post_metadate = sprintf(
		esc_html__( '%s on', 'magazinex-lite' ),
		$time_string
	);

	echo '<span class="post-metadate">' . $post_metadate . '</span>'; // WPCS: XSS OK.

}
endif;

// Human Date.
function magazinex_human_date() {
	printf( '<div class="date-meta">%s</div>',
		sprintf( _x( '%s ago', '%s = human-readable time difference', 'magazinex-lite' ),
		human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ) )
	);
}
//add_filter( 'magazinex_post_metadate', 'magazinex_human_date' );

if ( ! function_exists( 'magazinex_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time.
 */
function magazinex_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated screen-reader-text" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	// Wrap the time string in a link, and preface it with 'Posted on'.
	$posted_on = sprintf(
		/* translators: %s: post date */
		__( '<span class="screen-reader-text">Posted on</span> %s', 'magazinex-lite' ),
		'<span class="posted-on">' . $time_string . '</span>'
	);

	echo $posted_on;
}
endif;

if ( ! function_exists( 'magazinex_posted_by' ) ) :
/**
 * Prints HTML with meta information for the current author.
 */
function magazinex_posted_by() {

	$byline = sprintf(
		esc_html_x( ' by %s', 'post author', 'magazinex-lite' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);

	echo '<span class="byline">' . $byline . '</span>'; // WPCS: XSS OK.

}
endif;

if ( ! function_exists( 'magazinex_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function magazinex_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ' &middot; ', 'magazinex-lite' ) );
		if ( $categories_list && magazinex_categorized_blog() && get_theme_mod('hide_post_cats_bot') != true ) {
			echo '<span class="cat-links"><span class="screen-reader-text">' . esc_html__( 'Categories', 'magazinex-lite' ) . '</span>' . $categories_list . '</span>';
		}

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', '' );
		if ( $tags_list && get_theme_mod('hide_post_tags') != true ) {
			echo '<span class="tags-links"><span class="screen-reader-text">' . esc_html__( 'Tags', 'magazinex-lite' ) . '</span>' . $tags_list . '</span>';
		}
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		comments_popup_link( esc_html__( 'Leave a comment', 'magazinex-lite' ), esc_html__( '1 Comment', 'magazinex-lite' ), esc_html__( '% Comments', 'magazinex-lite' ) );
		echo '</span>';
	}

	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'magazinex-lite' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<br><span class="edit-link">',
		'</span>'
	);
}
endif;

if ( ! function_exists( 'magazinex_entry_tax' ) ) :
/**
 * Prints HTML with meta information for the categories and tags.
 */
function magazinex_entry_tax() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ' &middot; ', 'magazinex-lite' ) );
		if ( $categories_list && magazinex_categorized_blog() ) {
			printf( '<span class="cat-links">' . esc_html__( 'in %1$s', 'magazinex-lite' ) . '</span>', $categories_list ); // WPCS: XSS OK.
		}

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ', ', 'magazinex-lite' ) );
		if ( $tags_list ) {
			printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'magazinex-lite' ) . '</span>', $tags_list ); // WPCS: XSS OK.
		}
	}
}
endif;

if ( ! function_exists( 'magazinex_entry_cat' ) ) :
/**
 * Prints HTML with meta information for the categories only.
 */
function magazinex_entry_cat() {
	// Hide category and for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ' &middot; ', 'magazinex-lite' ) );
		if ( $categories_list && magazinex_categorized_blog() ) {
			printf( '<span class="cat-links">' . esc_html__( 'in %1$s', 'magazinex-lite' ) . '</span>', $categories_list ); // WPCS: XSS OK.
		}
	}
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function magazinex_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'magazinex_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'magazinex_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so magazinex_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so magazinex_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in magazinex_categorized_blog.
 */
function magazinex_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'magazinex_categories' );
}
add_action( 'edit_category', 'magazinex_category_transient_flusher' );
add_action( 'save_post',     'magazinex_category_transient_flusher' );

/**
 *	Commnets Link
 *-----------------------------------------------------------------*/
if( ! function_exists( 'magazinex_comment_link' ) ) :
	function magazinex_comment_link() {
		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link( esc_html__( 'Leave a comment', 'magazinex-lite' ), esc_html__( '1 Comment', 'magazinex-lite' ), esc_html__( '% Comments', 'magazinex-lite' ) );
			echo '</span>';
		}
	}
endif;

/**
 * List categories for specific taxonomy
 * @see the magazinex_get_term_color function is in a separate file
 * @link    http://codex.wordpress.org/Function_Reference/wp_get_post_terms
 */
if ( ! function_exists( 'magazinex_get_post_terms' ) ) {

	function magazinex_get_post_terms( $taxonomy = 'category', $first_only = false, $classes = '' ) {

		// Define return var
		$return = array();

		// Get terms
		$terms = wp_get_post_terms( get_the_ID(), $taxonomy );

		// Loop through terms and create array of links
		foreach ( $terms as $term ) {

			// Add classes
			$add_classes = 'post-term-'. $term->term_id;
			if ( $classes ) {
				$add_classes .= ' '. $classes;
			}
			if ( $add_classes ) {
				$add_classes = ' class="'. $add_classes .'"';
			}

			// Custom color for earch cat, see external.php
			$color = magazinex_get_term_color( $term->term_id, true );
			if ( $color ) {
				$color = ' style="background-color:'. $color .';"';
			}

			// Get permalink
			$permalink = get_term_link( $term->term_id, $taxonomy );

			// Add term to array
			$return[] = '<a href="'. esc_url( $permalink ) .'" title="'. esc_attr( $term->name ) .'"'. $add_classes . '' . $color . '>'. $term->name . '</a>';

		}

		// Return if no terms are found
		if ( ! $return ) {
			return;
		}

		// Return first category only
		if ( $first_only ) {	
			$return = $return[0];
		}

		// Turn terms array into comma seperated list
		else {
			$return = implode( '', $return );
		}

		// Return
		return $return;

	}

}

/**
 * Display category with color badge only
 * 
 * @link    http://codex.wordpress.org/Function_Reference/wp_get_post_terms
 */
if ( ! function_exists( 'magazinex_cat_badge' ) ) {

	function magazinex_cat_badge( $cat_id = '' ) {

		// Define return var
		$return = array();

		// Get cat
		$category = get_category( $cat_id );

		// Color meta
		$color = magazinex_get_term_color( $cat_id, true );

		if ( $color ) {
			$color = ' style="background-color: ' . $color . ' !important;" ';
		}

		// Output string
		$return[] = '<a ' . $color . 'href="' . esc_url( get_category_link( $category->term_id ) ) . '">' . $category->name . '</a>';


		// Return if empty
		if ( ! $return ) {
			return;
		}

		$return = implode( '', $return );


		// Return/Output
		// return $return;
		echo wp_kses( $return, 'post' );

	}

}

/**
 * Shown sub-categories with color meta of the parent category
 * @see magazinex_cat_badge()
 */
if ( ! function_exists( 'magazinex_subcat' ) ) {

	function magazinex_subcat( $parent_id = '' ) {

		$categories = get_categories( array( 'child_of' => $parent_id, 'hide_empty' => 1 ) );

		// Color meta
		$color = magazinex_get_term_color( $parent_id, true ); // get_term_meta( $parent_id, 'color', true );

		if ( $color ) {
			$color = ' style="color: ' . $color . ' !important;" ';
		}

  		foreach ($categories as $category) {
			$option = '<span><a href="' . esc_url( get_category_link( $category->term_id ) ) . '"' . $color . '>';
			$option .= $category->cat_name;
			$option .= ' ('.$category->category_count.')';
			$option .= '</a></span>';
			echo wp_kses( $option, 'post' );
  		}

	}

}

/**
 * Extracting the first's image of post
 */
if ( ! function_exists( 'magazinex_catch_image' ) ) :
	function magazinex_catch_image() {
  		global $post, $posts;
  		ob_start();
  		ob_end_clean();
  		$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);

			if ( 0 != $output ) {
		$first_img = $matches [1][0];
			}

			if ( empty($first_img) ) {
		$first_img = get_template_directory_uri() .'/img/no-image.png';
			}

   		return $first_img;
		}
endif;

/**
 * Tag Cloud Filter
 */
function magazinex_widget_tag_cloud_args( $args ) {
	$args = array(
		'number'   => 0,
		'unit' => 'px',
		'largest'    => 16,
		'smallest' => 11,
		'order' => 'RAND'
		);
	return $args;
}
//add_filter( 'widget_tag_cloud_args', 'magazinex_widget_tag_cloud_args' );

/**
 * Count Widgets to replace before_widget params
 * to do ? if ( is_active_widget( '', '', 'magazinex_icon_widget' ) )
 */
function magazinex_sidebar_params($params) {

    global $my_widget_num;
    $sidebar_id = $params[0]['id'];

    if ( $sidebar_id == 'home-widgets' ) {
    	$registered_widgets = wp_get_sidebars_widgets();
	$number_of_widgets = count( $registered_widgets[$sidebar_id] );

    	if ( !isset($registered_widgets[$sidebar_id]) || !is_array( $registered_widgets[$sidebar_id] ) || $number_of_widgets < 4 ) {
    	    	return $params;
    	}
    	if ( !$my_widget_num ) {
    	    	$my_widget_num = array();
    	}
    	if ( isset( $my_widget_num[$sidebar_id] ) ) {
        		$my_widget_num[$sidebar_id] ++;
    	} else {
        		$my_widget_num[$sidebar_id] = 1;
    	}
    	if ( $my_widget_num[$sidebar_id]/3-round($my_widget_num[$sidebar_id]/3)==0 && $my_widget_num[$sidebar_id] != count($registered_widgets[$sidebar_id]) ) {
        		$params[0]['after_widget'] = str_replace( '</div>', '</div></div><div class="row">', $params[0]['after_widget'] );
	}
    }
    return $params;

}
add_filter('dynamic_sidebar_params','magazinex_sidebar_params');

/**
 * List Categories
 */
if ( ! function_exists( 'magazinex_list_cat' ) ) :
	function magazinex_list_cat() {
		echo '<ul class="cat-list">';
			wp_list_categories('orderby=name&show_count=1&depth=1&number=&title_li=');
		echo '</ul>';
	}
	add_action( 'above_blog_section', 'magazinex_list_cat', 10 );
endif;

/**
 * Footer credits.
 */
function magazinex_txt_credits() {
	$text = sprintf( esc_html__( 'Powered by %s', 'magazinex-lite' ), '<a href="http://wordpress.org/">WordPress</a>' );
	$text .= '<span class="sep"> &middot; </span>';
	$text .= sprintf( esc_html__( 'Theme by %s', 'magazinex-lite' ), '<a href="http://dinevthemes.com/">DinevThemes</a>' );
	echo apply_filters( 'magazinex_txt_credits', $text );
}
add_action( 'magazinex_credits', 'magazinex_txt_credits' );

/**
 * Get first post with featured image in current query
 */
function magazinex_get_featured_post( $query = '' ) {
	if ( ! $query ) {
		global $wp_query;
		$query = $wp_query;
	}
	$posts = $query->posts;
	$posts_count = count( $posts );
	if ( $posts_count == 0 || class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) {
		return;
	}
	$post_with_thumb = 0;
	foreach ( $posts as $post ) {
		if ( has_post_thumbnail( $post->ID ) && ! is_sticky() ) {
			$post_with_thumb = $post->ID;
			break;
		}
	}
	return $post_with_thumb;
}

/**
 * List Categories
 */
function header_overlay_style() {
	if ( get_theme_mod( 'header_image_overlay' ) ) {
		$style = ' style="background-color: rgba(0, 0, 0, 0.' . esc_attr( get_theme_mod( 'header_image_overlay' ) ) . ');"';
		echo wp_kses( $style, array( '\'', '\"', '>', '+' ) );
	}
}